summaryrefslogtreecommitdiffstats
path: root/jjb/vpp/include-raw-vpp-parallel-vars.sh
diff options
context:
space:
mode:
authorjuraj.linkes <juraj.linkes@pantheon.tech>2018-10-11 17:09:29 +0200
committerJuraj Linkeš <juraj.linkes@pantheon.tech>2018-12-11 08:13:59 +0000
commit34e6385e3633c366ede6cac81b0a1decc1dfd83b (patch)
tree09804982810542506e49d2bf963cf038bdeb2152 /jjb/vpp/include-raw-vpp-parallel-vars.sh
parent940b95c902ccb4c6ef9f17098e14327512cd7443 (diff)
Enable nonvoting testing in VPP ARM verify jobs
Enable testing utilizing parallel test execution for ARM jobs with parallel test execution code, which has been merged in 1810 and update the OS for these jobs to Ubuntu1804. Create new jobs for branches without parallel test execution which don't have testing enabled and retain the OS. Also exclude some currently failing tests which will be enabled once the underlying issues are fixed. Change-Id: I5bbb1348a5a00676759753e5cf66ab65ce55e57d Signed-off-by: juraj.linkes <juraj.linkes@pantheon.tech>
Diffstat (limited to 'jjb/vpp/include-raw-vpp-parallel-vars.sh')
-rw-r--r--jjb/vpp/include-raw-vpp-parallel-vars.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/jjb/vpp/include-raw-vpp-parallel-vars.sh b/jjb/vpp/include-raw-vpp-parallel-vars.sh
index b4d5f209c..0926452f9 100644
--- a/jjb/vpp/include-raw-vpp-parallel-vars.sh
+++ b/jjb/vpp/include-raw-vpp-parallel-vars.sh
@@ -10,12 +10,12 @@ else
# NODE_NAME is jenkins-SOMEHEX
if [[ $NODE_NAME != $NODE_LABEL ]]
then
# Found label such as ubuntu1604arm-us
break
fi
done
- if [[ $NODE_LABEL == 'ubuntu1604arm-us' ]]
+ if [[ $NODE_LABEL == 'ubuntu1804arm-us' ]]
then
CORES=16
fi
@@ -24,4 +24,4 @@ fi
echo "Using MAKE_PARALLEL_FLAGS='-j $CORES' TEST_JOBS=$CORES for parallel build/test"
export MAKE_PARALLEL_FLAGS="-j $CORES"
-TEST_JOBS=$CORES
+export TEST_JOBS=$CORES
@@ -10,12 +10,12 @@ else
if [[ $NODE_NAME != $NODE_LABEL ]]
then
- # Found label such as ubuntu1604arm-us
+ # Found label such as ubuntu1804arm-us
break
fi